==> wiki3_4_4.zip: wiki3_4_4/plugin/bbs/BBSHandler.pm <==
############################################################
#
# Ǽǥץ饰Υϥɥ顣
#
############################################################
package plugin::bbs::BBSHandler;
#use strict;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# ν񤭹
#===========================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI;
	
	my $name    = $cgi->param("name");
	my $subject = $cgi->param("subject");
	my $message = $cgi->param("message");
	my $count   = $cgi->param("count");
	my $page    = $cgi->param("page");
	my $option  = $cgi->param("option");
	
	if($name eq ""){
		$name = "̵̾";
	} else {
		# post_nameȤǥå򥻥åȤ
		my $cookie = $cgi->cookie(-name=>'post_name',-value=>$name,-expires=>'+1M');
		print "Set-Cookie: ",$cookie->as_string,"\n";
	}
	
	if($subject eq ""){
		$subject = "̵";
	}
	
	if($page eq "" || $count eq ""){
		return $wiki->error("ѥ᡼Ǥ");
	} elsif($message eq ""){
		return $wiki->error("ʸϤƤ");
	}
	
	my @lines = split(/\n/,$wiki->get_page($page));
	my $flag       = 0;
	my $form_count = 1;
	my $content    = "";
	
	foreach(@lines){
		$content = $content.$_."\n";
		if(index($_," ")==0||index($_,"\t")==0){
			next;
		}
		if(index($_,"{{bbs")!=-1 && $flag==0){
			if($form_count==$count){
				$content .= "!!$subject - $name (".&Util::format_date(time()).")\n".
				            "$message\n";
				
				# no_commentץ
				if($option eq "no_comment"){
					
				# reverse_commentץ
				} elsif($option eq "reverce_comment"){
					$content .= "{{comment reverse}}\n";
				# ǥե
				} else {
					$content .= "{{comment}}\n";
				}
				$flag = 1;
				
			} else {
				$form_count++;
			}
		}
	}
	if($flag==1){
		$wiki->save_page($page,$content);
	}
	
	# Υڡ˥쥯Ȥ
	$wiki->redirect($page);
	#return $wiki->call_handler("");
}

1;

==> wiki3_5_0.zip: wiki3_5_0/plugin/bbs/BBSHandler.pm <==
############################################################
#
# Ǽǥץ饰Υϥɥ顣
#
############################################################
package plugin::bbs::BBSHandler;
#use strict;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# ν񤭹
#===========================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI;
	
	my $name    = $cgi->param("name");
	my $subject = $cgi->param("subject");
	my $message = $cgi->param("message");
	my $count   = $cgi->param("count");
	my $page    = $cgi->param("page");
	my $option  = $cgi->param("option");
	
	if($name eq ""){
		$name = "̵̾";
	} else {
		# post_nameȤǥå򥻥åȤ
		my $cookie = $cgi->cookie(-name=>'post_name',-value=>$name,-expires=>'+1M');
		print "Set-Cookie: ",$cookie->as_string,"\n";
	}
	
	if($subject eq ""){
		$subject = "̵";
	}
	
	if($page eq "" || $count eq ""){
		return $wiki->error("ѥ᡼Ǥ");
	} elsif($message eq ""){
		return $wiki->error("ʸϤƤ");
	}
	
	my @lines = split(/\n/,$wiki->get_page($page));
	my $flag       = 0;
	my $form_count = 1;
	my $content    = "";
	
	foreach(@lines){
		$content = $content.$_."\n";
		if(/^{{bbs\s*.*}}$/ && $flag==0){
			if($form_count==$count){
				$content .= "!!$subject - $name (".&Util::format_date(time()).")\n".
				            "$message\n";
				
				# no_commentץ
				if($option eq "no_comment"){
					
				# reverse_commentץ
				} elsif($option eq "reverce_comment"){
					$content .= "{{comment reverse}}\n";
				# ǥե
				} else {
					$content .= "{{comment}}\n";
				}
				$flag = 1;
				
			} else {
				$form_count++;
			}
		}
	}
	if($flag==1){
		$wiki->save_page($page,$content);
	}
	
	# Υڡ˥쥯Ȥ
	$wiki->redirect($page);
}

1;
